pub struct CacheStorageThreadHandle {
sender: GenericSender<CacheStorageThreadMessage>,
}Fields
sender: GenericSender<CacheStorageThreadMessage>Implementations
Sourceimpl CacheStorageThreadHandle
impl CacheStorageThreadHandle
pub fn new(sender: GenericSender<CacheStorageThreadMessage>) -> Self
Methods from Deref<Target = GenericSender<CacheStorageThreadMessage>>
pub fn send(&self, msg: T) -> Result<(), SendError>
Sourcepub fn send_or_warn(&self, msg: T)
pub fn send_or_warn(&self, msg: T)
Send a message T and log any error (instead of returning it).
In cases where channel closure is possible (because the receiver does not exist anymore), this convenience method can be used to ignore the result and log the error as a warning.
Sourcepub fn send_or_ignore(&self, msg: T)
pub fn send_or_ignore(&self, msg: T)
Send a message T and ignore the result
In cases where channel closure is expected to happen intermittently, and the sender
doesn’t care about the result, this is a short form for let _ = GenericSender::send();,
which makes the intent clearer.